@@ -1,7 +1,8 @@
-import requests
-import time
 import functools
 import importlib
+import time
+
+import requests
 
 django_keycloak_auth = importlib.import_module("django-keycloak-auth.keycloak")
 
@@ -157,16 +158,28 @@ class KeycloakWorker(django_keycloak_auth.KeycloakConnect):
     @token_decorator
     def get_group(self, is_code=None, name_type="hostname", group_name=None, suffix=suffix):
         groupname = group_name or f"{is_code}_{name_type}_{suffix}"
+        endpoint = self.groups_endpoint
+        if is_code != 'all':
+            endpoint += f"?search={groupname}"
         try:
-            resp = self.session.get(f'{self.server_url}{self.groups_endpoint}?search={groupname}',
-                                    headers=self.headers,
-                                    verify=self.verify)
+            resp = self.session.get(f'{self.server_url}{endpoint}', headers=self.headers, verify=self.verify)
             resp.raise_for_status()
             group = resp.json()
         except Exception as error:
             raise KeycloakException(f'Request for {groupname} group failed. Error: {error}')
         return group
 
+    @token_decorator
+    def get_group_details(self, group_uuid):
+        try:
+            resp = self.session.get(f'{self.server_url}{self.groups_endpoint}/{group_uuid}',
+                                    headers=self.headers, verify=self.verify)
+            resp.raise_for_status()
+            group = resp.json()
+        except Exception as error:
+            raise KeycloakException(f'Request for {group_uuid} group failed. Error: {error}')
+        return group
+
     @token_decorator
     def get_group_members(self, is_code, name_type="hostname", suffix=suffix):
         try:
@@ -175,7 +188,7 @@ class KeycloakWorker(django_keycloak_auth.KeycloakConnect):
                 return {'error': 'Group not found'}
             group_uuid = group[0]['id']
 
-            resp = requests.get(url=f"{self.server_url}{self.groups_endpoint}/{group_uuid}/members",
+            resp = requests.get(url=f"{self.server_url}{self.groups_endpoint}/{group_uuid}/members?max=-1",
                                 headers=self.headers,
                                 verify=self.verify)
             resp.raise_for_status()
@@ -261,10 +274,10 @@ class KeycloakWorker(django_keycloak_auth.KeycloakConnect):
         rolename = role_name or f"{is_code}:{name_type}:{suffix}"
         client_uuid = self.client_uuid or self.get_client_uuid()
         endpoint = self.roles_endpoint % {'client_uuid': client_uuid}
+        if role_name != 'all':
+            endpoint += f"?search={rolename}"
         try:
-            resp = requests.get(url=f"{self.server_url}{endpoint}?search={rolename}",
-                                headers=self.headers,
-                                verify=self.verify)
+            resp = requests.get(url=f"{self.server_url}{endpoint}", headers=self.headers, verify=self.verify)
             resp.raise_for_status()
             role = resp.json()
         except Exception as error:
@@ -287,6 +300,24 @@ class KeycloakWorker(django_keycloak_auth.KeycloakConnect):
         except Exception as error:
             raise KeycloakException(f'Request for creating {rolename} role failed. Error: {error}')
 
+    @token_decorator
+    def remove_role(self, role_uuid):
+        try:
+            resp = self.session.get(f'{self.server_url}{self.roles_endpoint}/{role_uuid}',
+                                    headers=self.headers, verify=self.verify)
+            resp.raise_for_status()
+        except Exception as error:
+            raise KeycloakException(f'Request for {role_uuid} role failed. Error: {error}')
+
+    @token_decorator
+    def remove_group(self, group_uuid):
+        try:
+            resp = self.session.delete(f'{self.server_url}{self.groups_endpoint}/{group_uuid}',
+                                       headers=self.headers, verify=self.verify)
+            resp.raise_for_status()
+        except Exception as error:
+            raise KeycloakException(f'Request for {group_uuid} group failed. Error: {error}')
+
     @token_decorator
     def create_group(self, is_code, name_type, suffix=suffix):
         groupname = f"{is_code}_{name_type}_{suffix}"
